@@ -1,3 +1,3 @@
 print("""Функция matrixg решает
 слау по Gauss and jacoby""")
-from .matrixg import matrix_1
\ No newline at end of file
+from .matrixg import *
\ No newline at end of file
